aboutsummaryrefslogtreecommitdiffstats
path: root/os/rt/src/chschd.c
diff options
context:
space:
mode:
Diffstat (limited to 'os/rt/src/chschd.c')
-rw-r--r--os/rt/src/chschd.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/os/rt/src/chschd.c b/os/rt/src/chschd.c
index f03c5eff3..572b2f822 100644
--- a/os/rt/src/chschd.c
+++ b/os/rt/src/chschd.c
@@ -159,7 +159,7 @@ static void wakeup(void *p) {
/* States requiring dequeuing.*/
queue_dequeue(tp);
}
- tp->p_u.rdymsg = RDY_TIMEOUT;
+ tp->p_u.rdymsg = MSG_TIMEOUT;
chSchReadyI(tp);
chSysUnlockFromISR();
}
@@ -169,7 +169,7 @@ static void wakeup(void *p) {
* timeout specification.
* @details The thread goes into a sleeping state, if it is not awakened
* explicitly within the specified timeout then it is forcibly
* awakened with a @p RDY_TIMEOUT low level message. The possible
* @ref thread_states are defined into @p threads.h.
*
* @param[in] newstate the new thread state
@@ -181,7 +181,7 @@ static void wakeup(void *p) {
* - @a TIME_IMMEDIATE this value is not allowed.
* .
* @return The wakeup message.
* @retval RDY_TIMEOUT if a timeout occurs.
*
* @sclass
*/
@@ -169,7 +169,7 @@ static void wakeup(void *p) {
* @details The thread goes into a sleeping state, if it is not awakened
* explicitly within the specified timeout then it is forcibly
- * awakened with a @p RDY_TIMEOUT low level message. The possible
+ * awakened with a @p MSG_TIMEOUT low level message. The possible
* @ref thread_states are defined into @p threads.h.
*
@@ -181,7 +181,7 @@ static void wakeup(void *p) {
* .
* @return The wakeup message.
- * @retval RDY_TIMEOUT if a timeout occurs.
+ * @retval MSG_TIMEOUT if a timeout occurs.
*
* @sclass